@@ -1,7 +1,7 @@
 #
 # This file is part of the PyMeasure package.
 #
-# Copyright (c) 2013-2017 PyMeasure Developers
+# Copyright (c) 2013-2022 PyMeasure Developers
 #
 # Permission is hereby granted, free of charge, to any person obtaining a copy
 # of this software and associated documentation files (the "Software"), to deal
@@ -23,17 +23,17 @@
 #
 
 import logging
-log = logging.getLogger(__name__)
-log.addHandler(logging.NullHandler())
 
 from pymeasure.instruments import Instrument
 from pymeasure.instruments.validators import (
     truncated_range, truncated_discrete_set,
     strict_discrete_set
 )
-from pymeasure.adapters import VISAAdapter
 from .buffer import KeithleyBuffer
 
+log = logging.getLogger(__name__)
+log.addHandler(logging.NullHandler())
+
 
 class Keithley2000(Instrument, KeithleyBuffer):
     """ Represents the Keithley 2000 Multimeter and provides a high-level
@@ -47,12 +47,12 @@ class Keithley2000(Instrument, KeithleyBuffer):
 
     """
     MODES = {
-        'current':'CURR:DC', 'current ac':'CURR:AC',
-        'voltage':'VOLT:DC', 'voltage ac':'VOLT:AC',
-        'resistance':'RES', 'resistance 4W':'FRES',
-        'period':'PER', 'frequency':'FREQ',
-        'temperature':'TEMP', 'diode':'DIOD',
-        'continuity':'CONT'
+        'current': 'CURR:DC', 'current ac': 'CURR:AC',
+        'voltage': 'VOLT:DC', 'voltage ac': 'VOLT:AC',
+        'resistance': 'RES', 'resistance 4W': 'FRES',
+        'period': 'PER', 'frequency': 'FREQ',
+        'temperature': 'TEMP', 'diode': 'DIOD',
+        'continuity': 'CONT'
     }
 
     mode = Instrument.control(
@@ -74,7 +74,7 @@ class Keithley2000(Instrument, KeithleyBuffer):
         """ A string property that enables or disables the system status beeper,
         which can take the values: :code:'enabled' and :code:'disabled'. """,
         validator=strict_discrete_set,
-        values={'enabled':1, 'disabled':0},
+        values={'enabled': 1, 'disabled': 0},
         map_values=True
     )
 
@@ -82,7 +82,8 @@ class Keithley2000(Instrument, KeithleyBuffer):
     # Current (A) #
     ###############
 
-    current = Instrument.measurement(":READ?",
+    current = Instrument.measurement(
+        ":READ?",
         """ Reads a DC or AC current measurement in Amps, based on the
         active :attr:`~.Keithley2000.mode`. """
     )
@@ -158,7 +159,8 @@ class Keithley2000(Instrument, KeithleyBuffer):
     # Voltage (V) #
     ###############
 
-    voltage = Instrument.measurement(":READ?",
+    voltage = Instrument.measurement(
+        ":READ?",
         """ Reads a DC or AC voltage measurement in Volts, based on the
         active :attr:`~.Keithley2000.mode`. """
     )
@@ -234,7 +236,8 @@ class Keithley2000(Instrument, KeithleyBuffer):
     # Resistance (Ohm) #
     ####################
 
-    resistance = Instrument.measurement(":READ?",
+    resistance = Instrument.measurement(
+        ":READ?",
         """ Reads a resistance measurement in Ohms for both 2-wire and 4-wire
         configurations, based on the active :attr:`~.Keithley2000.mode`. """
     )
@@ -303,7 +306,8 @@ class Keithley2000(Instrument, KeithleyBuffer):
     # Frequency (Hz) #
     ##################
 
-    frequency = Instrument.measurement(":READ?",
+    frequency = Instrument.measurement(
+        ":READ?",
         """ Reads a frequency measurement in Hz, based on the
         active :attr:`~.Keithley2000.mode`. """
     )
@@ -343,7 +347,8 @@ class Keithley2000(Instrument, KeithleyBuffer):
     # Period (s) #
     ##############
 
-    period = Instrument.measurement(":READ?",
+    period = Instrument.measurement(
+        ":READ?",
         """ Reads a period measurement in seconds, based on the
         active :attr:`~.Keithley2000.mode`. """
     )
@@ -383,7 +388,8 @@ class Keithley2000(Instrument, KeithleyBuffer):
     # Temperature (C) #
     ###################
 
-    temperature = Instrument.measurement(":READ?",
+    temperature = Instrument.measurement(
+        ":READ?",
         """ Reads a temperature measurement in Celsius, based on the
         active :attr:`~.Keithley2000.mode`. """
     )
@@ -431,28 +437,9 @@ class Keithley2000(Instrument, KeithleyBuffer):
     )
 
     def __init__(self, adapter, **kwargs):
-        super(Keithley2000, self).__init__(
+        super().__init__(
             adapter, "Keithley 2000 Multimeter", **kwargs
         )
-        # Set up data transfer format
-        if isinstance(self.adapter, VISAAdapter):
-            self.adapter.config(
-                is_binary=False,
-                datatype='float32',
-                converter='f',
-                separator=','
-            )
-
-    # TODO: Clean up error checking
-    def check_errors(self):
-        """ Read all errors from the instrument."""
-        while True:
-            err = self.values(":SYST:ERR?")
-            if int(err[0]) != 0:
-                errmsg = "Keithley 2000: %s: %s" % (err[0],err[1])
-                log.error(errmsg + '\n')
-            else:
-                break
 
     def measure_voltage(self, max_voltage=1, ac=False):
         """ Configures the instrument to measure voltage,
@@ -605,4 +592,4 @@ class Keithley2000(Instrument, KeithleyBuffer):
         :param frequency: A frequency in Hz between 65 Hz and 2 MHz
         :param duration: A time in seconds between 0 and 7.9 seconds
         """
-        self.write(":SYST:BEEP %g, %g" % (frequency, duration))
+        self.write(f":SYST:BEEP {frequency:g}, {duration:g}")
