@@ -104,7 +104,7 @@ class Channel():
 
     scale = Instrument.control(
         "SCALe?", "SCALe %f",
-        """ A float parameter that specifies the vertical scale, or units per division, in Volts."""
+        """A float parameter that specifies the vertical scale, or units per division, in Volts."""
     )
 
     def __init__(self, instrument, number):
@@ -245,10 +245,9 @@ class KeysightDSOX1102G(Instrument):
 
     def __init__(self, adapter, **kwargs):
         super().__init__(
-            adapter, "Keysight DSOX1102G Oscilloscope", **kwargs
+            adapter, "Keysight DSOX1102G Oscilloscope", timeout=6000, **kwargs
         )
         # Account for setup time for timebase_mode, waveform_points_mode
-        self.adapter.connection.timeout = 6000
         self.ch1 = Channel(self, 1)
         self.ch2 = Channel(self, 2)
 
