@@ -24,7 +24,6 @@
 
 from pymeasure.instruments import Instrument
 from pymeasure.instruments.validators import strict_discrete_set, truncated_discrete_set
-from .adapters import LakeShoreUSBAdapter
 
 from time import sleep
 import numpy as np
@@ -74,10 +73,18 @@ class LakeShore425(Instrument):
         map_values=True
     )
 
-    def __init__(self, port):
+    def __init__(self, adapter, **kwargs):
         super().__init__(
-            LakeShoreUSBAdapter(port),
+            adapter,
             "LakeShore 425 Gaussmeter",
+            asrl={'write_termination': "\n",
+                  'read_termination': "\n",  # from manual
+                  'baud_rate': 57600,
+                  'timeout': 500,
+                  'parity': 1,  # odd
+                  'data_bits': 7
+                  },
+            **kwargs
         )
 
     def auto_range(self):
