@@ -28,29 +28,15 @@ import pytest
 import os
 import tempfile
 from time import sleep
-from importlib.machinery import SourceFileLoader
 
 from pymeasure.experiment import Listener, Procedure
 from pymeasure.experiment.workers import Worker
 from pymeasure.experiment.results import Results
+from data.procedure_for_testing import RandomProcedure
 
 tcp_libs_available = bool(importlib.util.find_spec('cloudpickle')
                           and importlib.util.find_spec('zmq'))
 
-# Load the procedure, without it being in a module
-data_path = os.path.join(os.path.dirname(__file__), 'data/procedure_for_testing.py')
-RandomProcedure = SourceFileLoader('procedure', data_path).load_module().RandomProcedure
-# from data.procedure_for_testing import RandomProcedure
-
-
-def test_procedure():
-    """ Ensure that the loaded test procedure is properly functioning
-    """
-    procedure = RandomProcedure()
-    assert procedure.iterations == 100
-    assert procedure.delay == 0.001
-    assert hasattr(procedure, 'execute')
-
 
 def test_worker_stop():
     procedure = RandomProcedure()
